@@ -1,3 +1,4 @@
+use std::any::type_name;
 use std::ops::{Add, Deref, DerefMut};
 use std::str::FromStr;
 use std::time::SystemTime;
@@ -34,7 +35,12 @@ impl From<&chrono::NaiveTime> for TimeNative {
 impl serde::Serialize for TimeNative {
     #[inline]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where S: Serializer {
-        return serializer.serialize_str(&format!("TimeNative({})", self.inner));
+        use serde::ser::Error;
+        if type_name::<S::Error>().eq("rbson::ser::error::Error") {
+            return serializer.serialize_str(&format!("TimeNative({})", self.inner));
+        }else{
+            return self.inner.serialize(serializer);
+        }
     }
 }
 
