@@ -1,4 +1,5 @@
 use std::alloc::Layout;
+use std::any::type_name;
 use std::ops::{Deref, DerefMut};
 use rbson::Bson;
 use rbson::spec::BinarySubtype;
@@ -33,7 +34,12 @@ impl From<&time::OffsetDateTime> for TimestampZ {
 impl serde::Serialize for TimestampZ {
     #[inline]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where S: Serializer {
-        return serializer.serialize_str(&format!("TimestampZ({})", self.inner.unix_timestamp()));
+        use serde::ser::Error;
+        if type_name::<S::Error>().eq("rbson::ser::error::Error") {
+            return serializer.serialize_str(&format!("TimestampZ({})", self.inner.unix_timestamp()));
+        }else{
+            return self.inner.serialize(serializer);
+        }
     }
 }
 
